import request from '@/utils/request'

// 查询部门
export function getDepart () {
    return request({
      url: '/config/depart',
      method: 'GET'
    })
  }

// 新增部门
export function postDepart (data) {
    return request({
      url: '/config/depart',
      method: 'POST',
      data
    })
  }

// 删除部门
export function deleteDepart (id) {
    return request({
      url: `/config/depart/${id}`,
      method: 'DELETE'
    })
  }

// 编辑部门
export function putDepart (data) {
    return request({
      url: `/config/depart`,
      method: 'PUT',
      data
    })
  }

// 查询人员详情
export function getUser (id) {
    return request({
      url: `/config/user/${id}`,
      method: 'GET'
    })
}

// 新增人员 or 编辑人员
export function postUser (data, type) {
    return request({
      url: `/config/user`,
      method: type === 'edit' ? 'PUT' : 'POST',
      data
    })
}

// 新增人员时,查询手机号和工号是否已经存在,如果已经存在,则不能新加
export function getPhoneOrjobnumber (params) {
    return request({
      url: `/config/user/check`,
      method: 'GET',
      params
    })
}

// 筛选人员
export function searchUser (params) {
    return request({
      url: `/config/user`,
      method: 'GET',
      params
    })
}

// 查询人员详情
export function searchUserDetail (id) {
    return request({
      url: `/config/user/${id}`,
      method: 'GET'
    })
}

/**
 *
 * @param {Array} data 需要停用或者启动的i的数组
 * @param {*} type  1 停用  2 启用
 */

// 停用多个账号
export function stopUser (data, type) {
    return request({
      url: type === '1' ? `/config/user/stop` : '/config/user/enable',
      method: 'POST',
      data
    })
}

// 删除账户
export function deleteUser (data) {
    return request({
      url: `/config/user`,
      method: 'DELETE',
      data
    })
}

// 添加角色
export function postRole (data) {
    const { type } = data
    return request({
      url: `/config/role`,
      method: type === 'add' ? 'POST' : 'PUT',
      data
    })
}

// 查询角色
export function getRole (params) {
    return request({
      url: `/config/role`,
      method: 'GET',
      params
    })
}

// 删除角色
export function deleteRole (id) {
    return request({
      url: `/config/role/${id}`,
      method: 'DELETE'
    })
}

// 查询权限菜单
export function getRoleMenu (params) {
    return request({
      url: `/config/authority/menu`,
      method: 'GET',
      params
    })
}

/**
 *
 * @param {*} params  menuId  菜单id roleId 角色权限id
 */
// 查询权限按钮
export function getRoleButton (params) {
    return request({
      url: `/config/authority/button`,
      method: 'GET',
      params
    })
}

/**
 *
 * @param {*} params  menuId  菜单id roleId 角色权限id / buttonId  所有被选中按钮的id
 */
// 新增或者修改权限id
export function editRoleAuth (data) {
    return request({
      url: `/config/authority`,
      method: 'POST',
      data
    })
}

// 查询角色权限集合
export function getRoleAuth () {
    return request({
      url: `/config/authority`,
      method: 'GET'
    })
}
