import storage from 'store'
import { login } from '@/api/login'
import { getRoleAuth } from '@/api/role'
import { _token } from '@/utils/global'

// 递归后端的权限数据  -- 菜单
function filterPermissionArray (route) {
  const roleObj = {
    arr: [],
    buttonList: []
  }
  for (let i = 0; i < route.length; i++) {
    roleObj.arr.push(route[i].url)
    roleObj.buttonList.push(...route[i].buttons)

    if (route[i].children && route[i].children.length > 0) {
      const { arr, buttonList } = filterPermissionArray(route[i].children)
      roleObj.arr.push(...arr)
      roleObj.buttonList.push(...buttonList)
    }
  }
  return roleObj
}

const user = {
  namespaced: true,
  state: {
    token: '',
    name: '',
    welcome: '',
    avatar: '',
    roles: [],
    info: {}
  },

  mutations: {
    SET_TOKEN: (state, token) => {
      state.token = token
    },
    SET_NAME: (state, { name, welcome }) => {
      state.name = name
      state.welcome = welcome
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles
    },
    SET_INFO: (state, info) => {
      state.info = info
    }
  },

  actions: {
    // 用户登录
    Login ({ commit, dispatch }, params) {
      return new Promise(async (resolve, reject) => {
        commit('SET_ROLES', [])
        const { code, data } = await login(params)
        if (code === 0) {
          console.log(data)
          storage.set('user_info', data)
          storage.set(_token, data.token)
          // dispatch('getRoleAuth')
          resolve(data)
        } else {
          reject(data)
        }
      }).catch(e => e)
    },
    // 查询用户权限
    getRoleAuth ({ commit }) {
      return new Promise(async (resolve, reject) => {
        const { code, data } = await getRoleAuth()
        if (code === 0) {
          // 递归获取权限列表 --> 菜单权限
          const roleList = filterPermissionArray(data)
          console.log(roleList, '递归获取权限列表')
          commit('SET_ROLES', roleList.buttonList)
          resolve(roleList.arr)
        } else {
          reject(new Error('查询用户权限出错'))
        }
      }).catch(e => e)
    }

    // 登出
    // Logout ({ commit, state }) {
    //   return new Promise((resolve) => {
    //     logout(state.token).then(() => {
    //       commit('SET_TOKEN', '')
    //       commit('SET_ROLES', [])
    //       storage.remove(ACCESS_TOKEN)
    //       resolve()
    //     }).catch(() => {
    //       resolve()
    //     }).finally(() => {
    //     })
    //   })
    // }

  }
}

export default user
